@@ -328,9 +328,13 @@ def div_interval(self, other, Div, domain, dtype):
         else:
             return tmp, definiteRange
 
-    tmp1 = lb1_ub1.resolve()[0] if firstIsBoundsurf else lb1_ub1
+    r = direct_div(lb1_ub1, lb2_ub2)
+    return r, definiteRange
 
-    tmp2 = lb2_ub2.resolve()[0] if secondIsBoundsurf else lb2_ub2
+def direct_div(lb1_ub1, lb2_ub2):
+    tmp1 = lb1_ub1.resolve()[0] if isinstance(lb1_ub1, boundsurf) else lb1_ub1
+
+    tmp2 = lb2_ub2.resolve()[0] if isinstance(lb2_ub2, boundsurf) else lb2_ub2
 
     lb1, ub1 = tmp1[0], tmp1[1]
     lb2, ub2 = tmp2[0], tmp2[1]
@@ -338,8 +342,7 @@ def div_interval(self, other, Div, domain, dtype):
     tmp = vstack((td(lb1, lb2), td(lb1, ub2), td(ub1, lb2), td(ub1, ub2)))
     r = vstack((nanmin(tmp, 0), nanmax(tmp, 0)))
     update_div_zero(lb1, ub1, lb2, ub2, r)
-    return r, definiteRange
-
+    return r
 
 #def rdiv_interval(self, r, other, domain, dtype):
 #
