@@ -370,7 +370,7 @@ class boundsurf(object):#object is added for Python2 compatibility
 #            assert isBoundSurf2, 'bug or unimplemented yet (incorrect boundsurf.__mul__ type: %s)' % type(other)
 #            return other * self
             
-        R = rr if type(rr) in (boundsurf, boundsurf2) else boundsurf(rr[0], rr[1], definiteRange, domain)
+        R = rr if type(rr) in (boundsurf, boundsurf2) else boundsurf(surf({}, rr[0]), surf({}, rr[1]), definiteRange, domain)
         R = mul_handle_nan(R, R1, R2, domain)
         return R
     
@@ -610,6 +610,7 @@ def devided_interval(inp, r, domain, dtype, feasLB = -inf, feasUB = inf):
     
     for j, ind in enumerate(Inds[:-1]):
         if ind.size != 0:
+            assert ind.dtype != bool, 'error in FD kernel'
             tmp = defaultIntervalEngine(lb_ub, r.fun, r.d, monotonity=monotonities[j], convexity=convexities[j], 
                                         feasLB = feasLB, feasUB = feasUB, domain_ind = ind if ind.size != m else slice(None))[0]
             if ind.size == m:
@@ -657,7 +658,10 @@ def aux_mul_div_boundsurf(Elems, op, resolveSchedule=()):
     for elem in Elems:
         _R = elem.resolve()[0]
         lb, ub = _R
-        ind_positive, ind_negative, ind_z = Split(lb >= 0, ub <= 0)
+        
+        ind_positive, ind_negative, ind_z = \
+        Split(lb >= 0, ub <= 0) if op == operator.mul else Split(lb > 0, ub < 0)# TODO: improve for div
+        
         not_ind_negative = logical_not(ind_negative)
         changeSign = logical_xor(changeSign, ind_negative)
         indZ = logical_or(indZ, ind_z)
@@ -682,8 +686,13 @@ def aux_mul_div_boundsurf(Elems, op, resolveSchedule=()):
         if 1 and  _r[1].level == 1 and _r[0].b2equiv(_r[1]):
             rr = b2div(_r[0], _r[1])
             use_exp = False
-        else:
+        else:#if not any(all(_r[0].resolve()[0], 0)==0):# TODO: mb rework it
+            #print _r[0].resolve(), _r[1].resolve()
             rr = (_r[0].log() - _r[1].log())#.exp()
+#        else:
+#            from Interval import direct_div
+#            rr = direct_div( _r[0], _r[1])
+#            use_exp = False
     
 
     changeSign = logical_and(changeSign, logical_not(indZ))
@@ -970,13 +979,18 @@ def mul_handle_nan(R, R1, R2, domain):
 
 def b2mult(Self, Other):
     assert Self.level == Other.level == 1 and Self.b2equiv(Other)
-    k = list(Self.dep)[0]
-    ld = {k: Self.l.c*Other.l.d.get(k, 0.0) + Other.l.c*Self.l.d.get(k, 0.0)}
-    ud = {k: Self.u.c*Other.u.d.get(k, 0.0) + Other.u.c*Self.u.d.get(k, 0.0)}
-    ld2 = {k: Other.l.d.get(k, 0.0) * Self.l.d.get(k, 0.0)}
-    ud2 = {k: Other.u.d.get(k, 0.0) * Self.u.d.get(k, 0.0)}
     lc = Self.l.c * Other.l.c
     uc = Self.u.c * Other.u.c
+    if len(Self.dep):
+        k = list(Self.dep)[0]
+        ld = {k: Self.l.c*Other.l.d.get(k, 0.0) + Other.l.c*Self.l.d.get(k, 0.0)}
+        ud = {k: Self.u.c*Other.u.d.get(k, 0.0) + Other.u.c*Self.u.d.get(k, 0.0)}
+        ld2 = {k: Other.l.d.get(k, 0.0) * Self.l.d.get(k, 0.0)}
+        ud2 = {k: Other.u.d.get(k, 0.0) * Self.u.d.get(k, 0.0)}
+    else:
+        assert len(Other.dep) == 0
+        return boundsurf(surf({}, lc), surf({}, uc), Self.definiteRange & Other.definiteRange, Self.domain)
+        
     from boundsurf2 import surf2, boundsurf2
     ls, us = surf2(ld2, ld, lc), surf2(ud2, ud, uc)
     r = boundsurf2(ls, us, Self.definiteRange & Other.definiteRange, Self.domain)
