@@ -335,6 +335,9 @@ class oofun(OOFun):
     # overload "a+b"
     # @checkSizes
     def __add__(self, other):
+        if isinstance(other, ndarray) and other.dtype == object:
+            from ooarray import ooarray
+            return other.view(ooarray)+self
 #        if isinstance(other, Stochastic):
 #            return other.__add__(self)
         
@@ -518,6 +521,9 @@ class oofun(OOFun):
 
     # overload "a*b"
     def __mul__(self, other):
+        if isinstance(other, ndarray) and other.dtype == object:
+            from ooarray import ooarray
+            other = other.view(ooarray)
         if isinstance(other, OOArray):#if isinstance(other, (OOArray, Stochastic)):
             return other.__mul__(self)
         
